from setuptools import setup

setup(
    name='get_hc_secrets',
    version='1.5.2',
    packages=[],
    url='https://github.com/xmayeur/getSecrets',
    license='',
    author='Xavier Mayeur',
    author_email='xavier@mayeur.be',
    description='A package to read secrets from Hashicorp vault'
)
